@@ -1,3 +1,5 @@
+"""Local file handling."""
+
 import shutil
 import tempfile
 import time
@@ -7,7 +9,7 @@ from typing import List, Optional, Tuple
 
 import orjson
 from prometheus_client.parser import text_fd_to_metric_families
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict
 
 from arch_release_promotion.config import ProjectConfig, Settings
 from arch_release_promotion.gitlab import Upstream
@@ -22,7 +24,7 @@ TEMP_DIR_PREFIX = "arp-"
 
 
 def files_in_dir(path: Path) -> List[str]:
-    """Return the files in a directory as a list of strings
+    """Return the files in a directory as a list of strings.
 
     Parameters
     ----------
@@ -39,7 +41,6 @@ def files_in_dir(path: Path) -> List[str]:
     List[str]
         A list of strings representing the files in a directory
     """
-
     if not path.is_dir():
         raise RuntimeError(f"The path is not a path: {path}")
 
@@ -47,7 +48,7 @@ def files_in_dir(path: Path) -> List[str]:
 
 
 def get_version_from_artifact_release_dir(path: Path) -> str:
-    """Extrapolate the version of a given release path
+    """Extrapolate the version of a given release path.
 
     Parameters
     ----------
@@ -64,7 +65,6 @@ def get_version_from_artifact_release_dir(path: Path) -> str:
     str
         The version string for the release
     """
-
     if not path.is_dir():
         raise RuntimeError(f"The path for the release is not a directory: {path}")
 
@@ -76,19 +76,18 @@ def get_version_from_artifact_release_dir(path: Path) -> str:
 
 
 def create_temp_dir() -> Path:
-    """Create a temporary directory
+    """Create a temporary directory.
 
     Returns
     -------
     Path
         The path to the directory
     """
-
     return Path(tempfile.mkdtemp(prefix=TEMP_DIR_PREFIX))
 
 
 def remove_temp_dir(path: Path) -> None:
-    """Remove a temporary directory recursively
+    """Remove a temporary directory recursively.
 
     Parameters
     ----------
@@ -100,7 +99,6 @@ def remove_temp_dir(path: Path) -> None:
     RuntimeError
         If the to be removed path is not a directory or if its name does not contain TEMP_DIR_PREFIX
     """
-
     if not path.is_dir():
         raise RuntimeError(f"The path to remove is not a directory: {path}")
 
@@ -111,7 +109,7 @@ def remove_temp_dir(path: Path) -> None:
 
 
 def extract_zip_file_to_parent_dir(path: Path) -> None:
-    """Extract the contents of a ZIP file to the parent directory of that file
+    """Extract the contents of a ZIP file to the parent directory of that file.
 
     Parameters
     ----------
@@ -123,7 +121,6 @@ def extract_zip_file_to_parent_dir(path: Path) -> None:
     RuntimeError
         If the path does not specify a valid zip file
     """
-
     if not zipfile.is_zipfile(path):
         raise RuntimeError(f"The file is not a ZIP file: {path}")
 
@@ -132,7 +129,7 @@ def extract_zip_file_to_parent_dir(path: Path) -> None:
 
 
 def copy_signatures(source: Path, destination: Path) -> None:
-    """Copy any signature files from a source directory to a destination directory
+    """Copy any signature files from a source directory to a destination directory.
 
     Parameters
     ----------
@@ -146,7 +143,6 @@ def copy_signatures(source: Path, destination: Path) -> None:
     RuntimeError
         If either source or destination is not a directory
     """
-
     for path in [source, destination]:
         if not path.is_dir():
             raise RuntimeError("The specified path is not a directory: {path}")
@@ -157,7 +153,7 @@ def copy_signatures(source: Path, destination: Path) -> None:
 
 
 def write_release_info_to_file(release: Release, path: Path) -> None:
-    """Write a Release instance to a JSON file
+    """Write a Release instance to a JSON file.
 
     Parameters
     ----------
@@ -173,15 +169,16 @@ def write_release_info_to_file(release: Release, path: Path) -> None:
     OSError:
         If the file path is not writable
     """
-
     with open(path, "wb") as file:
         file.write(
-            orjson.dumps(release.dict(), option=orjson.OPT_INDENT_2 | orjson.OPT_APPEND_NEWLINE | orjson.OPT_SORT_KEYS)
+            orjson.dumps(
+                release.model_dump(), option=orjson.OPT_INDENT_2 | orjson.OPT_APPEND_NEWLINE | orjson.OPT_SORT_KEYS
+            )
         )
 
 
 def load_release_from_json_payload(path: Path) -> Release:
-    """Read a JSON payload and return it as a Release instance
+    """Read a JSON payload and return it as a Release instance.
 
     Parameters
     ----------
@@ -193,13 +190,12 @@ def load_release_from_json_payload(path: Path) -> Release:
     Release
         A Release instance reflecting the data from the JSON payload
     """
-
     with open(path, "r") as file:
         return Release(**orjson.loads(file.read()))
 
 
 def write_zip_file_to_parent_dir(path: Path, name: str = "promotion", format: str = "zip") -> None:
-    """Create ZIP file of all contents in a directory and write it to the directory's parent
+    """Create ZIP file of all contents in a directory and write it to the directory's parent.
 
     Parameters
     ----------
@@ -210,7 +206,6 @@ def write_zip_file_to_parent_dir(path: Path, name: str = "promotion", format: st
     format: str
         The compressed file format to use (defaults to "zip")
     """
-
     known_formats = ["zip", "tar", "gztar", "bztar", "xztar"]
     if len(name) < 1:
         raise RuntimeError("The file name has to be at least one char long, but empty string was provided.")
@@ -226,7 +221,7 @@ def read_metrics_file(
     size_metrics_names: Optional[List[str]],
     amount_metrics_names: Optional[List[str]],
 ) -> Tuple[List[AmountMetric], List[SizeMetric], List[VersionMetric]]:
-    """Read a metrics file that contains openmetrics based metrics and return those that match the respective keywords
+    """Read a metrics file that contains openmetrics based metrics and return those that match the respective keywords.
 
     Parameters
     ----------
@@ -244,14 +239,13 @@ def read_metrics_file(
     Tuple[List[AmountMetric], List[SizeMetric], List[VersionMetric]]:
         A Tuple with lists of AmountMetric, SizeMetric and VersionMetric instances derived from the input file
     """
-
     amount_metrics: List[AmountMetric] = []
     size_metrics: List[SizeMetric] = []
     version_metrics: List[VersionMetric] = []
 
     if path.exists():
         with open(path, "r") as file:
-            for metric in text_fd_to_metric_families(file):  # type: ignore[no-untyped-call]
+            for metric in text_fd_to_metric_families(file):
                 for sample in metric.samples:
                     if (
                         version_metrics_names
@@ -263,9 +257,9 @@ def read_metrics_file(
                     ):
                         version_metrics += [
                             VersionMetric(
-                                name=sample.labels.get("name"),
-                                description=sample.labels.get("description"),
-                                version=sample.labels.get("version"),
+                                name=sample.labels.get("name"),  # type: ignore[arg-type]
+                                description=sample.labels.get("description"),  # type: ignore[arg-type]
+                                version=sample.labels.get("version"),  # type: ignore[arg-type]
                             )
                         ]
                     if (
@@ -278,8 +272,8 @@ def read_metrics_file(
                     ):
                         size_metrics += [
                             SizeMetric(
-                                name=sample.labels.get("name"),
-                                description=sample.labels.get("description"),
+                                name=sample.labels.get("name"),  # type: ignore[arg-type]
+                                description=sample.labels.get("description"),  # type: ignore[arg-type]
                                 size=sample.value,
                             )
                         ]
@@ -293,9 +287,9 @@ def read_metrics_file(
                     ):
                         amount_metrics += [
                             AmountMetric(
-                                name=sample.labels.get("name"),
-                                description=sample.labels.get("description"),
-                                amount=sample.value,
+                                name=sample.labels.get("name"),  # type: ignore[arg-type]
+                                description=sample.labels.get("description"),  # type: ignore[arg-type]
+                                amount=int(sample.value),
                             )
                         ]
 
@@ -303,7 +297,7 @@ def read_metrics_file(
 
 
 def create_dir(path: Path) -> Path:
-    """Create a directory
+    """Create a directory.
 
     Parameters
     ----------
@@ -320,7 +314,6 @@ def create_dir(path: Path) -> Path:
     Path
         The path representing the existing, absolute directory
     """
-
     path = path.resolve(strict=False)
 
     if path.exists() and not path.is_dir():
@@ -332,7 +325,7 @@ def create_dir(path: Path) -> Path:
 
 
 class ProjectFiles(BaseModel):
-    """A pydantic model to operate on a project's files and releases
+    """A pydantic model to operate on a project's files and releases.
 
     Attributes
     ----------
@@ -347,12 +340,10 @@ class ProjectFiles(BaseModel):
     project_config: ProjectConfig
     upstream: Upstream
     promoted_releases: List[str]
-
-    class Config:
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
     def __init__(self, project_config: ProjectConfig, settings: Settings) -> None:
-        """A custom constructor to initialize an instance of ProjectFiles
+        """Initialize an instance of ProjectFiles.
 
         The names of the configured maximum number of promoted releases is retrieved using an Upstream instance.
         If the project's sync_dir does not exist, it will be created.
@@ -364,7 +355,6 @@ class ProjectFiles(BaseModel):
         settings: Settings
             A Settings instance used to initialize an Upstream instance
         """
-
         upstream = Upstream(
             url=settings.GITLAB_URL,
             private_token=None,
@@ -386,7 +376,7 @@ class ProjectFiles(BaseModel):
 
     @classmethod
     def sync(self, project_config: ProjectConfig, settings: Settings) -> None:
-        """A factory method to initialize an instance of ProjectFiles and synchronize all of its promoted_releases
+        """Initialize an instance of ProjectFiles and synchronize all of its promoted_releases.
 
         Parameters
         ----------
@@ -395,7 +385,6 @@ class ProjectFiles(BaseModel):
         settings: Settings
             A Settings instance used to initialize an Upstream instance
         """
-
         change_state: List[bool] = []
 
         project_files = self(
@@ -426,8 +415,7 @@ class ProjectFiles(BaseModel):
             project_files._set_last_update_file_timestamp()
 
     def _set_last_update_file_timestamp(self) -> None:
-        """Write the current seconds since the epoch to a "last update file" if it is configured"""
-
+        """Write the current seconds since the epoch to a "last update file" if it is configured."""
         if self.project_config.sync_config.last_updated_file:  # type: ignore
             print(f"Updating timestamp in {self.project_config.sync_config.last_updated_file}...")  # type: ignore
             with open(self.project_config.sync_config.last_updated_file, "w") as file:  # type: ignore
@@ -436,8 +424,7 @@ class ProjectFiles(BaseModel):
             print("Done!")
 
     def _remove_obsolete_releases(self) -> bool:
-        """Remove obsolete releases of a project from its sync_dir"""
-
+        """Remove obsolete releases of a project from its sync_dir."""
         state: List[bool] = []
         expected_dirs: List[Path] = []
         expected_files: List[Path] = []
@@ -472,8 +459,7 @@ class ProjectFiles(BaseModel):
         return any(state)
 
     def _set_latest_version_symlink(self) -> bool:
-        """Set the symlink to the latest version in a project's sync_dir"""
-
+        """Set the symlink to the latest version in a project's sync_dir."""
         state: List[bool] = []
 
         if self.promoted_releases:
@@ -500,7 +486,7 @@ class ProjectFiles(BaseModel):
         return any(state)
 
     def _sync_version(self, temp_dir_base: Optional[Path], version: str) -> bool:
-        """Synchronize a project's (release) version
+        """Synchronize a project's (release) version.
 
         Download a project release's promotion artifact and use it to establish whether the release version has been
         synchronized fully to the project's sync_dir.
@@ -519,7 +505,6 @@ class ProjectFiles(BaseModel):
         bool
             True if the synchronization introduced changes in the synchronization directory, False otherwise
         """
-
         with tempfile.TemporaryDirectory(prefix=TEMP_DIR_PREFIX, dir=temp_dir_base) as promotion_temp_dir_name:
             promotion_temp_dir = Path(promotion_temp_dir_name)
             extract_zip_file_to_parent_dir(
@@ -563,7 +548,7 @@ class ProjectFiles(BaseModel):
             return False
 
     def _is_release_type_synced(self, name: str, version: str) -> bool:
-        """Check whether a release type of a project's release version is synchronized fully already
+        """Check whether a release type of a project's release version is synchronized fully already.
 
         Parameters
         ----------
@@ -577,7 +562,6 @@ class ProjectFiles(BaseModel):
         bool
             True if the project's release type in the specified version is fully synchronized, False otherwise
         """
-
         release_base = self.project_config.sync_config.directory / Path(name)  # type: ignore
         release_json = release_base / Path(f"{name}-{version}.json")
         if not release_json.exists():
@@ -599,7 +583,7 @@ class ProjectFiles(BaseModel):
         self,
         version: str,
     ) -> bool:
-        """Evaluate whether a project's release requires syncing
+        """Evaluate whether a project's release requires syncing.
 
         Parameters
         ----------
@@ -611,7 +595,6 @@ class ProjectFiles(BaseModel):
         bool
             True if any of the release types of the project are not yet fully synchronized, False otherwise
         """
-
         release_type_states: List[bool] = []
         for project_release_type in self.project_config.releases:
             if not self._is_release_type_synced(
@@ -631,7 +614,7 @@ class ProjectFiles(BaseModel):
         source_base: Path,
         destination_base: Path,
     ) -> None:
-        """Copy promotion artifacts of a release type to its respective build artifact directory
+        """Copy promotion artifacts of a release type to its respective build artifact directory.
 
         Parameters
         ----------
@@ -642,7 +625,6 @@ class ProjectFiles(BaseModel):
         destination_base: Path
             The base directory in which the build artifacts of the release type are located
         """
-
         copy_signatures(
             source=source_base / Path(f"{release_type.name}/{release_type.name}-{release_type.version}"),
             destination=destination_base / Path(f"{release_type.name}/{release_type.name}-{release_type.version}"),
@@ -659,7 +641,7 @@ class ProjectFiles(BaseModel):
 
     @classmethod
     def validate_release_type_files(self, release_type: Release, path: Path) -> None:
-        """Validate the files of a release type
+        """Validate the files of a release type.
 
         Parameters
         ----------
@@ -673,7 +655,6 @@ class ProjectFiles(BaseModel):
         RuntimeError
             If one of the files is missing
         """
-
         print(f"Validating release type '{release_type.name}' version '{release_type.version}'...")
 
         json_payload = Path(f"{release_type.name}/{release_type.name}-{release_type.version}.json")
@@ -693,7 +674,7 @@ class ProjectFiles(BaseModel):
 
     @classmethod
     def move_release_type_to_sync_dir(self, release: Release, source_base: Path, sync_dir: Path) -> None:
-        """Move a validated version of a release type to a sync directory
+        """Move a validated version of a release type to a sync directory.
 
         Parameters
         ----------
@@ -704,7 +685,6 @@ class ProjectFiles(BaseModel):
         sync_dir: Path
             The directory to which the release type files are moved
         """
-
         print(f"Moving release type '{release.name}' version '{release.version}' to '{sync_dir}'...")
 
         release_type_base = sync_dir / Path(f"{release.name}")
